@@ -1,7 +1,7 @@
 use strict;
 use warnings;
 package Software::License::EUPL_1_2;
-$Software::License::EUPL_1_2::VERSION = '0.104002';
+$Software::License::EUPL_1_2::VERSION = '0.104003';
 use utf8;
 use parent 'Software::License';
 # ABSTRACT: The European Union Public License (EUPL) v1.2
@@ -25,16 +25,21 @@ Software::License::EUPL_1_2 - The European Union Public License (EUPL) v1.2
 
 =head1 VERSION
 
-version 0.104002
+version 0.104003
 
 =head1 PERL VERSION
 
 This module is part of CPAN toolchain, or is treated as such.  As such, it
-follows the agreement of the Perl Toolchain Gang to require no newer version of
-perl than v5.8.1.  This version may change by agreement of the Toolchain Gang,
-but for now is governed by the L<Lancaster
+follows the agreement of the Perl Toolchain Gang to require no newer version
+of perl than one released in the last ten years.  This version may change by
+agreement of the Toolchain Gang, but for now is governed by the L<Lancaster
 Consensus|https://github.com/Perl-Toolchain-Gang/toolchain-site/blob/master/lancaster-consensus.md>
-of 2013.
+of 2013 and the Lyon Amendment of 2023 (described at the linked-to document).
+
+Although it may work on older versions of perl, no guarantee is made that the
+minimum required version will not be increased.  The version may be increased
+for any reason, and there is no promise that patches will be accepted to
+lower the minimum required perl.
 
 =head1 AUTHOR
 
@@ -42,7 +47,7 @@ Ricardo Signes <rjbs@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2022 by Ricardo Signes.
+This software is copyright (c) 2023 by Ricardo Signes.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
