@@ -1,7 +1,7 @@
 use strict;
 use warnings;
 package Software::License::LGPL_2_1;
-$Software::License::LGPL_2_1::VERSION = '0.104002';
+$Software::License::LGPL_2_1::VERSION = '0.104003';
 use parent 'Software::License';
 # ABSTRACT: GNU Lesser General Public License, Version 2.1
 
@@ -23,16 +23,21 @@ Software::License::LGPL_2_1 - GNU Lesser General Public License, Version 2.1
 
 =head1 VERSION
 
-version 0.104002
+version 0.104003
 
 =head1 PERL VERSION
 
 This module is part of CPAN toolchain, or is treated as such.  As such, it
-follows the agreement of the Perl Toolchain Gang to require no newer version of
-perl than v5.8.1.  This version may change by agreement of the Toolchain Gang,
-but for now is governed by the L<Lancaster
+follows the agreement of the Perl Toolchain Gang to require no newer version
+of perl than one released in the last ten years.  This version may change by
+agreement of the Toolchain Gang, but for now is governed by the L<Lancaster
 Consensus|https://github.com/Perl-Toolchain-Gang/toolchain-site/blob/master/lancaster-consensus.md>
-of 2013.
+of 2013 and the Lyon Amendment of 2023 (described at the linked-to document).
+
+Although it may work on older versions of perl, no guarantee is made that the
+minimum required version will not be increased.  The version may be increased
+for any reason, and there is no promise that patches will be accepted to
+lower the minimum required perl.
 
 =head1 AUTHOR
 
@@ -40,7 +45,7 @@ Ricardo Signes <rjbs@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2022 by Ricardo Signes.
+This software is copyright (c) 2023 by Ricardo Signes.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
@@ -54,7 +59,7 @@ Version 2.1, February 1999
 
   (The master copy of this license lives on the GNU website.)
 
-Copyright (C) 1991, 1999 Free Software Foundation, Inc. 59
+Copyright (C) 1991, 1999 Free Software Foundation, Inc.
 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 
 Everyone is permitted to copy and distribute verbatim copies
